@@ -109,15 +109,15 @@ async def generate(request: ImageRequest, n: int = 30):  # 兼容dalle3
 
 # VideoResult
 if __name__ == '__main__':
-    api_key = "8c1fd8923a2f4c0eb323335ca4ba9f98.I7FisfQS7x1zYK8P"
+    api_key = "03bdb799cbcb4a8cac609f9d5ebe02e7.snp1yga8VEEzO2bk"
 
     # api_key = "c98aa404b0224690b211c5d1e420db2c.qGaByuJATne08QUx"
     # api_key = "7d10426c06afa81e8d7401d97781249c.DbqlSsicRtaUdKXI"  # 新号
     # api_key = "e21bd630f681c4d90b390cd609720483.WSFVgA3Kk1wNCX0mN"
 
     request = VideoRequest(
-        model='cogvideox-flash',
-        # model='cogvideox-3',
+        # model='cogvideox-flash',
+        model='cogvideox-3',
 
     )
     r = arun(create_task(request, api_key=api_key))
