@@ -18,10 +18,14 @@ from meutils.apis.fal.images import generate as fal_generate
 
 from meutils.apis.gitee.image_to_3d import generate as image_to_3d_generate
 from meutils.apis.gitee.openai_images import generate as gitee_images_generate
-from meutils.apis.qwen.chat import Completions as QwenCompletions
 from meutils.apis.volcengine_apis.images import generate as volc_generate
 from meutils.apis.images.recraft import generate as recraft_generate
 from meutils.apis.jimeng.images import generate as jimeng_generate
+# from meutils.apis.google.images import generate as google_generate
+
+from meutils.apis.qwen.chat import Completions as QwenCompletions
+from meutils.apis.google.chat import Completions as GoogleCompletions
+from meutils.apis.google.images import openai_generate
 
 
 async def generate(
@@ -29,20 +33,7 @@ async def generate(
         api_key: Optional[str] = None,
         base_url: Optional[str] = None,
 ):
-    if base_url:  # 优先级最高
-        data = {
-            **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
-            **(request.extra_fields or {})
-        }
-        request = ImageRequest(**data)
-        if request.model.startswith("doubao"):
-            request.watermark = False
-            if request.image and isinstance(request.image, list):
-                request.image = request.image[0]
-
-        data = to_openai_params(request)
-        client = AsyncClient(api_key=api_key, base_url=base_url)
-        return await client.images.generate(**data)
+    logger.debug(request)
 
     if request.model.startswith("fal-ai"):  # 主要 request.image
         return await fal_generate(request, api_key)
@@ -51,12 +42,12 @@ async def generate(
         request = RecraftImageRequest(**request.model_dump(exclude_none=True))
         return await recraft_generate(request)
 
-    if request.model.startswith(("seededit", "jimeng")):  # 即梦
-        return await jimeng_generate(request)
-
-    if request.model.startswith(("seed", "seededit_v3.0", "byteedit_v2.0")):
+    if request.model.startswith(("seed", "seededit_v3.0", "byteedit_v2.0", "i2i_portrait_photo")):  # seededit seedream
         return await volc_generate(request, api_key)
 
+    if request.model.startswith(("jimeng")):  # 即梦
+        return await jimeng_generate(request)
+
     if request.model in {"Hunyuan3D-2", "Hi3DGen", "Step1X-3D"}:
         return await image_to_3d_generate(request, api_key)
 
@@ -68,9 +59,34 @@ async def generate(
             request.image = request.image[-1]
         return await QwenCompletions(api_key=api_key).generate(request)
 
+    if request.model.startswith(("google/gemini", "gemini")):  # openrouter
+        if api_key.endswith("-openai"):
+            api_key = api_key.removesuffix("-openai")
+            return await openai_generate(request, base_url=base_url, api_key=api_key)
+        else:
+            return await GoogleCompletions(base_url=base_url, api_key=api_key).generate(request)  # 原生接口
+
+    # 其他
+    data = {
+        **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
+        **(request.extra_fields or {})
+    }
+    request = ImageRequest(**data)
+    if request.model.startswith("doubao"):
+        request.watermark = False
+        if request.image and isinstance(request.image, list):
+            request.image = request.image[0]
+
+    data = to_openai_params(request)
+    client = AsyncClient(api_key=api_key, base_url=base_url)
+    return await client.images.generate(**data)
+
 
 # "flux.1-krea-dev"
 
 if __name__ == '__main__':
     # arun(generate(ImageRequest(model="flux", prompt="笑起来")))
-    arun(generate(ImageRequest(model="FLUX_1-Krea-dev", prompt="笑起来")))
+    # arun(generate(ImageRequest(model="FLUX_1-Krea-dev", prompt="笑起来")))
+
+    token = f"""{os.getenv("VOLC_ACCESSKEY")}|{os.getenv("VOLC_SECRETKEY")}"""
+    arun(generate(ImageRequest(model="seed", prompt="笑起来"), api_key=token))
