@@ -44,4 +44,4 @@ async def get_api_key_money(api_key):
 if __name__ == '__main__':
     # arun(get_api_key_money(os.getenv("OPENAI_API_KEY_GUOCHAN")))
 
-    arun(get_api_key_money(""))
+    arun(get_api_key_money("sk-WEmN6rbcmEu5jRUT5c6b2d672119435c999d308bCc124009"))
