@@ -42,7 +42,6 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         "req_key": "high_aes_general_v30l_zt2i",
         # "req_key": "jimeng_high_aes_general_v21_L",
 
-        "prompt": request.prompt,
         "seed": request.seed,
         "width": 1328,
         "height": 1328,
@@ -53,17 +52,16 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         # "use_rephraser": True
     }
 
-    image, prompt = request.image_and_prompt
-    width, height = map(int, request.size.split('x'))
-
-    if image:
-        payload["image_urls"] = [image]
+    if request.image_urls:
+        payload["image_urls"] = request.image_urls
         payload["req_key"] = request.model
         if payload["req_key"] not in {"seededit_v3.0", "byteedit_v2.0"}:
             payload["req_key"] = "byteedit_v2.0"  # "seededit_v3.0" https://www.volcengine.com/docs/85128/1602254
 
+    width, height = map(int, request.size.split('x'))
     payload['width'] = width
     payload['height'] = height
+    payload['prompt'] = request.prompt
 
     if request.response_format == "oss_url":
         payload["return_url"] = False
@@ -91,21 +89,22 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
 
 if __name__ == '__main__':
     token = f"""{os.getenv("VOLC_ACCESSKEY")}|{os.getenv("VOLC_SECRETKEY")}"""
-    token = "AKLTOWM5ZTc5ZDFhZWNlNDIzODkwYmZiNjEyNzYwNzE0MTI|T0RCbFpHRTJaRFEyWmpjeE5ERXpNR0ptWlRCaU16WmhPRE0wWVdKa01tTQ=="
     prompt = """
     3D魔童哪吒 c4d 搬砖 很开心， 很快乐， 精神抖擞， 背景是数不清的敖丙虚化 视觉冲击力强 大师构图 色彩鲜艳丰富 吸引人 背景用黄金色艺术字写着“搬砖挣钱” 冷暖色对比
     """
 
-    # prompt = """
-    # https://oss.ffire.cc/files/kling_watermark.png
-    # 让这个女人带上眼镜 衣服换个颜色
-    # """
+    prompt = """
+    
+    让这个女人带上眼镜 衣服换个颜色
+    """
 
     request = ImageRequest(
-        model="high_aes_general_v30l_zt2i",
+        # model="high_aes_general_v30l_zt2i",
+        model="seededit_v3.0",
         prompt=prompt,
         response_format="url",
         size="512x1328",
+        # image="https://oss.ffire.cc/files/kling_watermark.png"
     )
 
     arun(generate(request, token=token))
