@@ -28,10 +28,10 @@ from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request,
 FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=8W6kk8"  # 超刷
 
 
-async def get_valid_token(tokens: Optional[list] = None, force_update: bool = True):
+async def get_valid_token(tokens: Optional[list] = None, force_update: bool = True, batch_size: int = 1):
     tokens = tokens or await get_series(FEISHU_URL, duplicated=True)
 
-    if token := await redis_aclient.get("volc-token"):
+    if token := await redis_aclient.get("volc-token"):  # list
         token = token.decode()
 
         if force_update:  # 强制检测更新
@@ -41,12 +41,13 @@ async def get_valid_token(tokens: Optional[list] = None, force_update: bool = Tr
                 await redis_aclient.delete("volc-token")  # 删除无效
         else:
             return token
-
-    for token in tokens:
+    for i, token in enumerate(tokens, 1):
         if await check(token):
             await redis_aclient.set("volc-token", token, ex=2 * 3600 - 10 * 60)
 
             return token
+        if batch_size == i:
+            break
 
     logger.debug(f"无效 {token}")
     _ = f"{time.ctime()}\n\n{FEISHU_URL}\n\n所有token无效\n\n{token}"
