@@ -152,8 +152,11 @@ async def to_url(
         headers: Optional[dict] = None,
 
         content_type: Optional[str] = None,
-        mime_type: Optional[str] = None
+        mime_type: Optional[str] = None,
+
 ):
+    if not file: return
+
     content_type = content_type or mime_type
 
     if isinstance(file, list):
@@ -161,8 +164,6 @@ async def to_url(
         urls = await asyncio.gather(*tasks)
         return urls
 
-    if not file: return
-
     file = await to_bytes(file, headers=headers)
     file_url = await Minio().upload(file, filename, content_type=content_type)
     return file_url
@@ -210,7 +211,13 @@ async def to_file(file: Union[UploadFile, str, bytes], filename: Optional[str] =
         return Path(filename).resolve()
 
 
-async def markdown_base64_to_url(text, pattern=r'!\[Image_\d+\]\((.+?)\)'):
+async def markdown_base64_to_url(text, pattern=r'!\[.*?\]\((.*?)\)'):
+    """
+    :param text:
+    :param pattern:
+        pattern=r'!\[.*?\]\((data:image/.*?)\)'
+    :return:
+    """
     base64_strings = re.findall(pattern, text)
 
     # logger.debug(text)
@@ -327,9 +334,20 @@ if __name__ == '__main__':
     # url = "https://lmdbk.com/5.mp4"
     # url = "https://v3.fal.media/files/kangaroo/y5-1YTGpun17eSeggZMzX_video-1733468228.mp4"
     # content = requests.get(url).content
+    #
+    # url = "https://fal.media/files/koala/8teUPbRRMtAUTORDvqy0l.mp4"
+    #
+    # with timer():
+    #     # arun(get_file_duration(content=content))
+    #     arun(get_file_duration(url=url))
 
-    url = "https://fal.media/files/koala/8teUPbRRMtAUTORDvqy0l.mp4"
+    # r = arun(to_url([]))
+    text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
 
-    with timer():
-        # arun(get_file_duration(content=content))
-        arun(get_file_duration(url=url))
+    arun(markdown_base64_to_url(
+        text=text,
+        # pattern=r'!\[.*?\]\((data:image/.*?)\)'
+        # pattern=r'!\[.*?\]\((.*?)\)'
+
+    )
+    )
