@@ -7,6 +7,7 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
+import os
 
 from meutils.pipe import *
 from meutils.caches import rcache
@@ -227,7 +228,7 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
 
             payload = {
                 # "model": "doubao-seedance-1-0-pro-250528",
-                "model":"doubao-seedance-1-0-lite-i2v-250428",
+                "model": "doubao-seedance-1-0-lite-i2v-250428",
                 "content": [
                     {
                         "type": "text",
@@ -316,7 +317,7 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
 
 
 @retrying()
-@rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
+# @rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_fal(token, threshold: float = 0):
     try:
         # data = await AsyncClient(key=token).upload(b'', '', '')
@@ -358,6 +359,32 @@ async def check_token_for_gitee(api_key, threshold: float = 1):
         return False
 
 
+@retrying()
+# @rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
+async def check_token_for_openrouter(api_key, threshold: float = 1):
+    if not isinstance(api_key, str):
+        return await check_tokens(api_key, check_token_for_openrouter)
+
+    try:
+        # {"data": {"total_credits": 215.00205323, "total_usage": 215.20147321775545}} %
+        client = AsyncOpenAI(base_url=os.getenv("OPENROUTER_BASE_URL"), api_key=api_key)
+        data = await client.get("/credits", cast_to=object)
+        # logger.debug(data)
+        # data = await client.get("/models/user", cast_to=object)
+        # logger.debug(bjson(data))
+
+        #
+        # logger.debug(bjson(data))
+
+        return True
+    except TimeoutException as e:
+        raise
+
+    except Exception as e:
+        logger.error(f"Error: {e}\n{api_key}")
+        return False
+
+
 async def get_valid_token_for_fal(feishu_url: Optional[str] = None):
     feishu_url = feishu_url or "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=iFRwmM"
     _ = await get_next_token(feishu_url, check_token_for_fal, ttl=600)
@@ -400,9 +427,9 @@ if __name__ == '__main__':
 
     # arun(check_token_for_ppinfra("sk_F0kgPyCMTzmOH_-VCEJucOK8HIrbnLGYm_IWxBToHZQ"))
 
-    # arun(check_token_for_volc("c720b2fb-e2be-42a7-a9e5-0a42c29d5766"))
+    # arun(check_token_for_volc("827b41d2-7e8c-46e2-9854-0720ca1bd2e4"))
     # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))
-    arun(check_token_for_volc("8a5af7cb-42a3-4391-ac40-9d0f4502acde", purpose='seedance'))
+    # arun(check_token_for_volc("8a5af7cb-42a3-4391-ac40-9d0f4502acde", purpose='seedance'))
 
     # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))
 
@@ -410,8 +437,12 @@ if __name__ == '__main__':
 
     # arun(check_token_for_fal("56d8a95e-2fe6-44a6-8f7d-f7f9c83eec24:537f06b6044770071f5d86fc7fcd6d6f"))
 
-    # arun(check_token_for_ppinfra("sk_ib2EjSVnXfB5hSlVuckpejRNXLIU3MaD1wxvXnsvdxQ", threshold=18000))
+    # arun(check_token_for_ppinfra("sk_4Ja29OIUBVwKo5GWx-PRTsRcTyxxRjZDpYxSdPg75QU", threshold=18000))
 
     # arun(check_token_for_gitee("NWVXUPI38OQVXZGOEL3D23I9YUQWZPV23GVVBW1X"))
 
     # arun(get_valid_token_for_fal())
+
+    api_key = "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"
+    # api_key = None
+    arun(check_token_for_openrouter(api_key=api_key or os.getenv("OPENROUTER_API_KEY")))
