@@ -22,14 +22,15 @@ models_mapping = {
     "deepseek-v3.1": "deepseek-ai/DeepSeek-V3.1",
     "deepseek-v3-1-250821": "deepseek-ai/DeepSeek-V3.1",
 
-
     "qwen3-32b": "Qwen/Qwen3-32B",
     "deepseek-r1": "deepseek-ai/DeepSeek-R1",
     "deepseek-r1-250528": "deepseek-ai/DeepSeek-R1",
     "deepseek-reasoner": "deepseek-ai/DeepSeek-R1",
     "qwen2.5-72b-instruct": "Qwen/Qwen2.5-72B-Instruct-128K",
+
+    "kimi-k2-250711": "moonshotai/Kimi-K2-Instruct",
     "kimi-k2-0711-preview": "moonshotai/Kimi-K2-Instruct",
-    "moonshotai/kimi-k2-instruct": "moonshotai/Kimi-K2-Instruct",
+
     "qwen2.5-vl-32b-instruct": "Qwen/Qwen2.5-VL-32B-Instruct",
     "qwen2.5-vl-72b-instruct": "Qwen/Qwen2.5-VL-72B-Instruct",
     "qwen2.5-vl-7b-instruct": "Qwen/Qwen2.5-VL-7B-Instruct",
