@@ -134,24 +134,31 @@ class ImageRequest(BaseModel):  # openai
             self.size = self.size if 'x' in self.size else '512x512'
 
     @cached_property
-    def image_urls(self):
+    def image_urls(self) -> List[str]:
         if self.image:
             if isinstance(self.image, str):
                 return [self.image]
             else:
                 return self.image
+        else:
+            image, _ = self.image_and_prompt
+            if image:
+                return [image]
+
         return []
 
     @cached_property
     def image_and_prompt(self):  # image prompt 目前是单图
         if self.prompt.startswith('http') and (prompts := self.prompt.split(maxsplit=1)):
             if len(prompts) == 2:
+                self.prompt = prompts[-1]
                 return prompts
             else:
                 return prompts + [' ']  # 只有 单url
 
         elif "http" in self.prompt and (images := parse_url(self.prompt)):
-            return images[0], self.prompt.replace(images[0], "")
+            self.prompt = self.prompt.replace(images[0], "")
+            return images[0], self.prompt
 
         else:
             return None, self.prompt
@@ -605,29 +612,40 @@ if __name__ == '__main__':
 
     prompt = "https://oss.ffire.cc/files/kling_watermark.png 带个眼镜"
     # prompt = "带个眼镜 https://oss.ffire.cc/files/kling_watermark.png"
-    prompt = "https://oss.ffire.cc/files/kling_watermark.png"
-    prompt = "画条狗"
+    # prompt = "https://oss.ffire.cc/files/kling_watermark.png"
+    # prompt = "画条狗"
 
-    request = ImageRequest(prompt=prompt)
-    print(request.image_and_prompt)
+    request = ImageRequest(
+        prompt=prompt,
 
-    data = {"image[]": "xxx"}
-    r = ImageRequest(**data)
+        # size="16x9",
 
-    data = {
-        "model": "flux-kontext-pro",
-        "prompt": "a cat and a dog",
-        "size": "512x1024",
-        # "aspect_ratio": "16:9"
-    }
+        aspect_ratio="16:9"
+    )
+    #
+    # print(request.prompt)
+    #
+    # print(request.image_urls)
+    # print(request.image_and_prompt)
+    # print(request.prompt)
 
-    dd = {
-        "model": "flux-kontext-pro",
-        "prompt": "a cat and a dog",
-        "size": "5121x1024",
-        # "aspect_ratio": "16:9"
-    }
-
-    r = ImageRequest(**data)
+    # data = {"image[]": "xxx"}
+    # r = ImageRequest(**data)
+    #
+    # data = {
+    #     "model": "flux-kontext-pro",
+    #     "prompt": "a cat and a dog",
+    #     "size": "512x1024",
+    #     # "aspect_ratio": "16:9"
+    # }
+    #
+    # dd = {
+    #     "model": "flux-kontext-pro",
+    #     "prompt": "a cat and a dog",
+    #     "size": "5121x1024",
+    #     # "aspect_ratio": "16:9"
+    # }
+    #
+    # r = ImageRequest(**data)
 
     # print(ImagesResponse())
