@@ -52,7 +52,7 @@ class ChannelInfo(BaseModel):
     access_token: str = ''
     openai_organization: str = ''
     test_model: str = ''
-    status: int = 1
+    status: int = 1  # 开启
     weight: int = 0
     created_time: int = Field(default_factory=lambda: int(time.time()))
     test_time: int = 0
@@ -85,11 +85,15 @@ class ChannelInfo(BaseModel):
 
     """参数覆盖"""
     param_override: Union[str, dict] = ''  # json
+    header_override: Union[str, dict] = ''  # json
     is_tools: bool = False
 
     # new
     max_input_tokens: int = 0
-    multi_key_mode: str = "random"
+
+    mode:Optional[Literal["multi_to_single"]] = None
+    multi_key_mode: Literal['random', 'polling'] = "polling"
+    key_mode: Optional[Literal['append', 'replace']] = None
 
     def __init__(self, /, **data: Any):
         super().__init__(**data)
@@ -113,6 +117,9 @@ class ChannelInfo(BaseModel):
         if isinstance(self.param_override, dict):
             self.param_override = json.dumps(self.param_override)
 
+        if isinstance(self.header_override, dict):
+            self.header_override = json.dumps(self.header_override)
+
         if isinstance(self.setting, dict):
             self.setting = json.dumps(self.setting)
 
