@@ -101,6 +101,11 @@ FAL_MODELS = {
     "fal-ai/wan/v2.2-5b/text-to-video": 0.15 * FAL_,
     "fal-ai/wan/v2.2-5b/image-to-video": 0.15 * FAL_,
 
+    # pika
+    "fal-ai/pika/v2.2/text-to-video": 0.45 * FAL,
+    "fal-ai/pika/v2.2/image-to-video": 0.45 * FAL,
+    "fal-ai/pika/v2.2/pikascenes": 0.45 * FAL,
+
 }
 
 FAL_MODELS = {
@@ -110,11 +115,18 @@ FAL_MODELS = {
 MODEL_PRICE = {
     **FAL_MODELS,
 
+    "nano-banana": 0.04 * 3,
+    "gemini-2.5-flash-image": 0.04 * 3,
+    "gemini-2.5-flash-image-preview": 0.03,
+    "gemini-2.5-flash-image-preview-hd": 0.08,
+
     "qwen-image": 0.05,
     "qwen-image-edit": 0.05,
 
     "wan-ai-wan2.1-t2v-14b": 1,
     "wan-ai-wan2.1-t2v-14b-turbo": 1,
+    "wan2-1-14b-i2v-250225": 1,
+    "wan2-1-14b-t2v-250225": 1,
 
     "async-task": 0.0001,
     "chatfire-claude": 0.02,
@@ -174,9 +186,8 @@ MODEL_PRICE = {
     "doubao-seedream-3-0-t2i-250415": 0.1,
     "doubao-seededit-3-0-i2i-250628": 0.1,
 
+    "doubao-seedance-1-0-pro": 0.5,  # 480 1080
     "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
-    "api-doubao-seedance-1-0-pro-250528-1080p": 2,  # 480 1080
-    "api-doubao-seedance-1-0-pro-250528-480p": 0.5,  # 480 1080
 
     "doubao-seedance-1-0-lite-t2v-250428": 0.4,
     "doubao-seedance-1-0-lite-i2v-250428": 0.4,
@@ -266,6 +277,7 @@ MODEL_PRICE = {
     "api-images-seededit": 0.1,
 
     "seedream-3.0": 0.05,
+    "seededit-3.0": 0.05,
     "chat-seedream-3.0": 0.05,
 
     "seededit": 0.1,
@@ -654,6 +666,9 @@ MODEL_RATIO = {
     "moonshotai/kimi-k2-instruct": 2,
     "kimi-k2-0711-preview": 2,
     "kimi-k2-turbo-preview": 2,
+    "kimi-k2-250711": 2,
+    "kimi-k2-250905": 2,
+    "kimi-k2-0905-preview": 2,
 
     # 智谱 https://www.bigmodel.cn/pricing
     'glm-4-9b-chat': 0.1,
@@ -698,6 +713,8 @@ MODEL_RATIO = {
     "qwen-max-latest": 1.2 * 1,
     "qwen2.5-max": 1.2 * 1,
     "qwen-max-2025-01-25": 1.2 * 1,
+    "qwen3-max": 3,
+    "qwen3-max-preview": 3,
 
     "qwen-vl-max-latest": 1.5,
     "qwen-vl-plus-latest": 0.75,
@@ -1065,6 +1082,7 @@ MODEL_RATIO = {
     "gemini-2.5-pro-preview-05-06": 0.625,
     "gemini-2.5-pro-preview-06-05": 0.625,
     "gemini-2.5-pro": 0.625,
+    "gemini-2.5-pro-nothinking": 0.625,
 
     "gemini-1.5-pro-001": 1.25,
     "gemini-1.5-pro-002": 1.25,
@@ -1243,6 +1261,9 @@ COMPLETION_RATIO = {
     "moonshotai/kimi-k2-instruct": 4,
     "kimi-k2-0711-preview": 4,
     "kimi-k2-turbo-preview": 4,
+    "kimi-k2-250711": 4,
+    "kimi-k2-250905": 4,
+    "kimi-k2-0905-preview": 4,
 
     "moonshot-v1-8k": 5,
     "moonshot-v1-32k": 4,
@@ -1409,6 +1430,12 @@ COMPLETION_RATIO = {
     "gemini-2.5-pro-preview-03-25": 8,
     "gemini-2.5-pro-preview-05-06": 8,
     "gemini-2.5-pro-preview-06-05": 8,
+    "gemini-2.5-pro-think": 8,
+
+    "gemini-2.5-pro-thinking": 8,
+    "gemini-2.5-pro-exp-03-25-thinking":8,
+    "gemini-2.5-pro-preview-03-25-thinking": 8,
+    "gemini-2.5-pro-nothinking": 8,
 
     "gemma2-9b-it": 4,
     "gemma2-27b-it": 4,
@@ -1420,11 +1447,7 @@ COMPLETION_RATIO = {
     "gemini-2.5-flash-preview-05-20-thinking": 23,
     "gemini-2.5-flash-preview-05-20": 8.4,
     "gemini-2.5-flash-preview-05-20-nothinking": 8.4,
-    "gemini-2.5-pro-think": 4,
 
-    "gemini-2.5-pro-thinking": 4,
-    "gemini-2.5-pro-exp-03-25-thinking": 4,
-    "gemini-2.5-pro-preview-03-25-thinking": 4,
 
     "hunyuan-a52b-instruct": 5,
     "qwen2.5-coder-32b-instruct": 3,
@@ -1437,6 +1460,9 @@ COMPLETION_RATIO = {
 
     "qwen-long": 4,
     "qwen-max": 4,
+    "qwen3-max": 4,
+    "qwen3-max-preview": 4,
+
     "qwen-vl-max-latest": 3,
     "qwen-vl-plus-latest": 3,
 
