@@ -640,4 +640,4 @@ if __name__ == '__main__':
     #
     # print(chat_completion_chunk)
 
-    print(ImageRequest(prompt='xx'))
+    # print(ImageRequest(prompt='xx'))
